<?php

namespace mod_gradeimporter\event;

defined('MOODLE_INTERNAL') || die();

class gradeimporter_submission_created extends \core\event\base {
    
    protected function init() {
        $this->data['crud'] = 'c';
        $this->data['edulevel'] = self::LEVEL_PARTICIPATING;
    }

    /**
    *Returns the description of what happened
    *
    *@return string
    */ 
    public function get_description(){
        return "The user with id '$this->userid' has created a submission " . 
                "on the grade importer with the course module id '$this->contextinstanceid'." ; 
    }

    /**
     * Returns localised event name
     * 
     * @return string
     */
    public static function get_name(){
        return get_string('eventmodelsubmissioncreated', 'mod_gradeimporter');
    }

    /**
     * Get URL related to the action
     * 
     * @return \moodle_url
     */
    public function get_url(){
        $url = new \moodle_url('/mod/gradeimporter/view.php', array('id' => $this->contextinstanceid));
        return $url;
    }

    /**
     * Return the legacy event log data.
     * 
     * @return array|null
     */
    protected function get_legacy_logdata(){
        //the legacy log table expects a relative path to /mod/model/
        $logurl = new \moodle_url('/mod/gradeimporter/view.php', array('id' => $this->contextinstanceid));
        return array($this->courseid, 'gradeimporter', 'editgradeimporter', $logurl, 
                        $this->other['gradeimporterid'], $this->gradeimporterid);
    }

    /**
     * Custom validation
     * 
     * @throws \coding_exception
     * @return void
     */
    protected function validate_data(){
        parent::validate_data();
        if ($this->contextlevel != CONTEXT_MODULE) {
            throw new \coding_exception('Context level must be CONTEXT_MODULE');
        }
    }
}